-----------------
Async Callback
-----------------

.. literalinclude:: ../../../../../examples/user/async_callback.py
    :caption: See `async_callback.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/async_callback.py>`_ on GitHub.

-----------------
Async Greetings
-----------------

.. literalinclude:: ../../../../../examples/user/async_greetings.py
    :caption: See `async_greetings.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/async_greetings.py>`_ on GitHub.

-----------------
Async ordered responses
-----------------

.. literalinclude:: ../../../../../examples/user/async_ordered.py
    :caption: See `async_ordered.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/async_ordered.py>`_ on GitHub.

-----------------
Async tokenize
-----------------

.. literalinclude:: ../../../../../examples/user/async_tokenize.py
    :caption: See `async_tokenize.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/async_tokenize.py>`_ on GitHub.
